#
# spec file for package gst123
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012-2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gst123
Version:        0.4.1
Release:        1.4
Summary:        GStreamer based Command Line Music Player
License:        LGPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://space.twc.de/~stefan/gst123.php
Source:         https://github.com/swesterfeld/gst123/releases/download/%{version}/%{name}-%{version}.tar.bz2
Source1:        gst123.desktop
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(ncurses) >= 5

%description
The gst123 program is a command line player akin to ogg123 or mpg123,
but uses gstreamer for decoding, so supports all the codecs gstreamer
knows.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install
install -D -m0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%suse_update_desktop_file -r "%{name}" AudioVideo Player
%find_lang "%{name}" || echo -n >"%{name}.lang"

%files -f "%{name}.lang"
%license COPYING
%doc AUTHORS NEWS
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/applications/%{name}.desktop

%changelog
* Wed Aug 30 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1
  * Avoid depending using .git / git during build (remove
    ChangeLog).
  version 0.4.0:
  * Use gtk3 instead of gtk2.
  * Change config file location to ~/.config/gst123rc
  * Decode URIs to print proper media name.
  * Support "audio/mpegurl" mime type for m3u playlist parser as
    well.
  * Various bugfixes.
* Sun Feb  4 2018 jengelh@inai.de
- Compact description.
* Fri Feb  2 2018 aloisio@gmx.com
- Update to version 0.3.5
  * Support faster/slower playback [David Fries].
  * Better status bar notification (on the same line as time).
  * Minor bugfixes.
- Drop gst123.ncurses.patch (merged upstream)
- Spec cleanup
* Fri Feb 10 2017 olaf@aepfle.de
- Update to version 0.3.4.20160601.c2edb28:
  - Option parsing bug for "-@, --list" fixed.
  - Avoid annoying redundant tag updates.
  - Support video subtitles [Ahmed El-Mahmoudy].
  - Use A/a keys to set video opacity [Ahmed El-Mahmoudy].
  - Work around kwin window manager policy "focus stealing prevention".
  - Fix image filetype detection bug.
  - Fix Issue 14: Use sync bus handler to set window xid.
  - Fix Issue 13: In some cases playing videos leads to g_criticals().
  - Added "-f, --fullscreen" option to start playback in fullscreen mode.
  - Added "--volume" option to set initial playback volume.
  - Ignore symlinks when crawling directories.
  - Various bugfixes.
* Wed Apr 23 2014 ohering@suse.de
- BuildRequire glib2-devel >= 2.32 due to GMutex/GCond usage
* Mon Jul 29 2013 malcolmlewis@opensuse.org
- Update to version 0.3.3:
  + Fix Issue 10: Local files not properly escaped when converted
    to URLs.
  + Added "-k, --skip=" option: skip first 'n' seconds
    [Tobias Bengfort].
- Updates from version 0.3.2:
  + Support building with gstreamer 1.0 or gstreamer 0.10
    (Issue 11).
  + Added "-a pulse" PulseAudio output support.
  + Fix time display updates (broken by introduction of quiet
    mode).
  + Properly quit player if none of the files in the playlist can
    be played.
  + Cleanup code to avoid compiler warnings.
- Rebase gst123-gtk2_backport_GDK_BLANK_CURSOR.patch.
* Sun Apr 22 2012 pascal.bleser@opensuse.org
- update to 0.3.1:
  * added quiet mode
  * ignore image files during playback
  * added keybinding 'n' for 'play next file'
* Thu Mar 29 2012 pascal.bleser@opensuse.org
- update to 0.3.0:
  * support visualization plugins during audio playback
* Fri Feb 17 2012 pascal.bleser@opensuse.org
- update to 0.2.2:
  * disable screensaver during video playback (via xdg-screensaver)
  * fixed includes to compile with gcc-4.7
  * fixed a problem with fullscreen/unfullscreen
* Sun Sep  4 2011 pascal.bleser@opensuse.org
- update to 0.2.1:
  * fixed minor memory leak
  * fix warnings due to wrong glib option parsing
  * use wikihtml2man for documentation (replaces old doxer based manpage)
* Tue Apr 12 2011 pascal.bleser@opensuse.org
- update to 0.2.0:
  * the behavior of the options --shuffle, --repeat, and --random is now
    identical to ogg123
  * the colon character is now supported in filenames
  * the "none" audio driver was added, which disables audio output
  * the --full-version option is supported, which prints versions of the
    libraries used by gst123
  * minor fixes were made
* Sun Jan 16 2011 pascal.bleser@opensuse.org
- update to 0.1.4:
  * a crash for "dumb" terminals was fixed
* Sun Nov 28 2010 pascal.bleser@opensuse.org
- update to 0.1.3:
  * support for m3u and pls playlists was added
  * JACK audio output is available now
  * the audio driver can be set using a configuration file (or on the command line, as before)
* Mon Jul  5 2010 pascal@links2linux.de
- update to 0.1.2:
  * adds an -a option to select the audio driver (OSS/ALSA) and device (/dev/dsp1, hw:1)
  * fixes a crash triggered when closing the video window
* Sat Jun 26 2010 pascal@links2linux.de
- update to 0.1.1:
  * the code was fixed to allow URIs in playlists
- changes from 0.1.0:
  * proper support for watching video files with gst123 has been added,
    including a full screen mode (f) and using keys (like page up, cursor left,
    etc.) within the video window
  * also hides the mouse in the video widget and uses the correct aspect ratio during zoom
  * GStreamer playbin2 is now used instead of playbin
  * option parsing was improved (--help, --help-gst, and --help-gtk work)
  * the ability to disable video stream (-x, --novideo) was added
  * pause / muted state is now printed in the status display
* Tue May 11 2010 pascal@links2linux.de
- update to 0.0.3:
  * fixes buggy key handling when keys are autorepeating
  * restores proper terminal settings after Ctrl+Z
  * adds keys for mute and volume control
  * displays the video codec when present
* Mon May  3 2010 pascal@links2linux.de
- initial package: 0.0.2
